@@ -119,29 +119,16 @@ class Service:
                         "--certificatesresolvers.letsencrypt.acme.httpchallenge.entrypoint=http",
                     ],
                     "ports": {"80/tcp": 80, "443/tcp": 443},
-                    # "healthcheck": {
-                    #     "test": [
-                    #         "CMD",
-                    #         "wget",
-                    #         "--no-verbose",
-                    #         "--tries=1",
-                    #         "--spider",
-                    #         "http://localhost/ping",
-                    #     ],
-                    #     "interval": "1m30s",
-                    #     "timeout": "10s",
-                    #     "retries": 3,
-                    #     "start_period": "1s",
-                    # },
                     "labels": {
                         "backplane.enabled": "true",
                         "traefik.http.routers.traefik.rule": "Host(`" + self.url + "`)",
                         "traefik.http.middlewares.compress.compress": "true",
                         "traefik.http.routers.traefik.service": "api@internal",
-                        "traefik.http.middlewares.secured.chain.middlewares": "default-headers",
+                        "traefik.http.middlewares.secured.chain.middlewares": "default-headers,auth",
                         "traefik.http.middlewares.https-redirect.redirectScheme.scheme": "https",
                         "traefik.http.middlewares.https-redirect.redirectScheme.permanent": "true",
                         # "traefik.http.middlewares.default-whitelist.ipwhitelist.sourceRange": "10.0.0.0/8,192.168.0.0/16,127.0.0.1/32,172.0.0.0/8",
+                        "traefik.http.middlewares.auth.basicauth.users": f"{self.config.user}:{self.config.password_hash}",
                         "traefik.http.middlewares.default-headers.headers.frameDeny": "true",
                         "traefik.http.middlewares.default-headers.headers.sslRedirect": "true",
                         "traefik.http.middlewares.default-headers.headers.browserXssFilter": "true",
